@@ -34,6 +34,9 @@
 #include <gio/gio.h>
 
 #include <libmtp.h>
+#if HAVE_LIBUSB
+#include <libusb.h>
+#endif
 
 #include "gvfsbackendmtp.h"
 #include "gvfsicon.h"
@@ -76,7 +79,11 @@
  * Constants
  ************************************************/
 
+#if HAVE_LIBUSB
+#define EVENT_POLL_PERIOD { 3600, 0 }
+#else
 #define EVENT_POLL_PERIOD { 1, 0 }
+#endif
 
 /************************************************
  * Private Types
@@ -596,6 +603,8 @@ on_uevent (GUdevClient *client, gchar *action, GUdevDevice *device, gpointer use
     op_backend->force_unmounted = TRUE;
     g_atomic_int_set (&op_backend->unmount_started, TRUE);
     g_vfs_backend_force_unmount ((GVfsBackend*)op_backend);
+
+    g_signal_handlers_disconnect_by_func (op_backend->gudev_client, on_uevent, op_backend);
   }
 
   g_debug ("(I) on_uevent done.\n");
@@ -627,7 +636,6 @@ check_event (gpointer user_data)
 {
   GVfsBackendMtp *backend = user_data;
 
-  LIBMTP_event_t event;
   while (!g_atomic_int_get (&backend->unmount_started)) {
     int ret;
     LIBMTP_mtpdevice_t *device = backend->device;
@@ -855,7 +863,7 @@ get_dev_path_and_device_from_host (GVfsJob *job,
     g_free (dev_path);
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("Couldn't find matching udev device."));
+                              _("Couldn’t find matching udev device."));
     return NULL;
   }
 
@@ -906,9 +914,7 @@ do_mount (GVfsBackend *backend,
   op_backend->volume_symbolic_icon = g_vfs_get_volume_symbolic_icon (device);
   g_object_unref (device);
 
-  op_backend->on_uevent_id =
-    g_signal_connect_object (op_backend->gudev_client, "uevent",
-                             G_CALLBACK (on_uevent), op_backend, 0);
+  g_signal_connect (op_backend->gudev_client, "uevent", G_CALLBACK (on_uevent), op_backend);
 
   op_backend->file_cache = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
@@ -960,6 +966,10 @@ do_unmount (GVfsBackend *backend, GVfsJobUnmount *job,
 
   g_atomic_int_set (&op_backend->unmount_started, TRUE);
 
+#if HAVE_LIBUSB
+  libusb_interrupt_event_handler (NULL);
+#endif
+
 #ifdef HAVE_LIBMTP_1_1_12
   /* Thread will terminate after flag is set. */
   g_thread_join (op_backend->event_thread);
@@ -984,8 +994,9 @@ do_unmount (GVfsBackend *backend, GVfsJobUnmount *job,
   g_hash_table_unref (op_backend->file_cache);
 
   g_source_remove (op_backend->hb_id);
-  g_signal_handler_disconnect (op_backend->gudev_client,
-                               op_backend->on_uevent_id);
+
+  g_signal_handlers_disconnect_by_func (op_backend->gudev_client, on_uevent, op_backend);
+
   g_object_unref (op_backend->gudev_client);
   g_clear_pointer (&op_backend->dev_path, g_free);
   g_clear_pointer (&op_backend->volume_name, g_free);
@@ -1067,7 +1078,7 @@ get_device (GVfsBackend *backend, const char *id, GVfsJob *job) {
       if (device == NULL) {
         g_vfs_job_failed (G_VFS_JOB (job),
                           G_IO_ERROR, G_IO_ERROR_FAILED,
-                          _("Unable to open MTP device '%s'"), name);
+                          _("Unable to open MTP device “%s”"), name);
         g_free (name);
         goto exit;
       }
@@ -1435,7 +1446,7 @@ do_query_info (GVfsBackend *backend,
       LIBMTP_Clear_Errorstack (device);
       g_vfs_job_failed_literal (G_VFS_JOB (job),
                                 G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                                _("Directory doesn't exist"));
+                                _("Directory doesn’t exist"));
       goto exit;
     }
 
@@ -1460,7 +1471,7 @@ do_query_info (GVfsBackend *backend,
       g_debug ("(W) storage %X not found?!\n", entry->storage);
       g_vfs_job_failed_literal (G_VFS_JOB (job),
                                 G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                                _("Directory doesn't exist"));
+                                _("Directory doesn’t exist"));
       goto exit;
     }
   } else {
@@ -1610,7 +1621,7 @@ do_make_directory (GVfsBackend *backend,
   if (!entry) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("Directory doesn't exist"));
+                              _("Directory doesn’t exist"));
     goto exit;
   }
 
@@ -1656,7 +1667,7 @@ do_pull (GVfsBackend *backend,
   if (entry == NULL) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("File doesn't exist"));
+                              _("File doesn’t exist"));
     goto exit;
   } else if (entry->id == -1) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
@@ -1672,7 +1683,7 @@ do_pull (GVfsBackend *backend,
   if (file == NULL) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("File doesn't exist"));
+                              _("File doesn’t exist"));
     goto exit;
   }
 
@@ -1712,12 +1723,12 @@ do_pull (GVfsBackend *backend,
       } else if (source_is_dir && dest_is_dir) {
         g_vfs_job_failed_literal (G_VFS_JOB (job),
                                   G_IO_ERROR, G_IO_ERROR_WOULD_MERGE,
-                                  _("Can't merge directories"));
+                                  _("Can’t merge directories"));
         goto exit;
       } else if (source_is_dir && !dest_is_dir) {
         g_vfs_job_failed_literal (G_VFS_JOB (job),
                                   G_IO_ERROR, G_IO_ERROR_WOULD_RECURSE,
-                                  _("Can't recursively copy directory"));
+                                  _("Can’t recursively copy directory"));
         goto exit;
       }
       /* Source and Dest are files */
@@ -1740,7 +1751,7 @@ do_pull (GVfsBackend *backend,
   } else if (source_is_dir) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_WOULD_RECURSE,
-                              _("Can't recursively copy directory"));
+                              _("Can’t recursively copy directory"));
     goto exit;
   }
 
@@ -1993,7 +2004,7 @@ do_push (GVfsBackend *backend,
   if (!parent) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("Directory doesn't exist"));
+                              _("Directory doesn’t exist"));
     goto exit;
   }
 
@@ -2037,12 +2048,12 @@ do_push (GVfsBackend *backend,
       } else if (source_is_dir && dest_is_dir) {
         g_vfs_job_failed_literal (G_VFS_JOB (job),
                                   G_IO_ERROR, G_IO_ERROR_WOULD_MERGE,
-                                  _("Can't merge directories"));
+                                  _("Can’t merge directories"));
         goto exit;
       } else if (source_is_dir && !dest_is_dir) {
         g_vfs_job_failed_literal (G_VFS_JOB (job),
                                   G_IO_ERROR, G_IO_ERROR_WOULD_RECURSE,
-                                  _("Can't recursively copy directory"));
+                                  _("Can’t recursively copy directory"));
         goto exit;
       }
       /* Source and Dest are files */
@@ -2066,7 +2077,7 @@ do_push (GVfsBackend *backend,
   } else if (source_is_dir) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_WOULD_RECURSE,
-                              _("Can't recursively copy directory"));
+                              _("Can’t recursively copy directory"));
     goto exit;
   }
 
@@ -2126,7 +2137,7 @@ do_delete (GVfsBackend *backend,
   if (entry == NULL) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("File doesn't exist"));
+                              _("File doesn’t exist"));
     goto exit;
   } else if (entry->id == -1) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
@@ -2189,7 +2200,7 @@ do_set_display_name (GVfsBackend *backend,
   if (entry == NULL) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("File doesn't exist"));
+                              _("File doesn’t exist"));
     goto exit;
   } else if (entry->id == -1) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
@@ -2257,7 +2268,7 @@ do_open_for_read (GVfsBackend *backend,
   if (entry == NULL) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("File doesn't exist"));
+                              _("File doesn’t exist"));
     goto exit;
   } else if (entry->id == -1) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
@@ -2279,7 +2290,7 @@ do_open_for_read (GVfsBackend *backend,
     LIBMTP_destroy_file_t (file);
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_IS_DIRECTORY,
-                             _("Can't open directory"));
+                             _("Can’t open directory"));
     goto exit;
   }
 
@@ -2351,7 +2362,7 @@ do_open_icon_for_read (GVfsBackend *backend,
       g_vfs_job_failed (G_VFS_JOB (job),
                         G_IO_ERROR,
                         G_IO_ERROR_NOT_FOUND,
-                        _("No thumbnail for entity '%s'"),
+                        _("No thumbnail for entity “%s”"),
                         icon_id);
       goto exit;
     }
@@ -2369,7 +2380,7 @@ do_open_icon_for_read (GVfsBackend *backend,
     g_vfs_job_failed (G_VFS_JOB (job),
                       G_IO_ERROR,
                       G_IO_ERROR_INVALID_ARGUMENT,
-                      _("Malformed icon identifier '%s'"),
+                      _("Malformed icon identifier “%s”"),
                       icon_id);
     goto exit;
   }
@@ -2536,7 +2547,7 @@ do_create (GVfsBackend *backend,
   if (!entry) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("Directory doesn't exist"));
+                              _("Directory doesn’t exist"));
     goto exit;
   }
 
@@ -2611,7 +2622,7 @@ do_append_to (GVfsBackend *backend,
   if (entry == NULL) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-                              _("File doesn't exist"));
+                              _("File doesn’t exist"));
     goto exit;
   } else if (entry->id == -1) {
     g_vfs_job_failed_literal (G_VFS_JOB (job),
